@@ -167,10 +167,22 @@ def main():
     env.filters['secured'] = lambda x: len(x.get('security', [])) > 0
     env.filters['sec_def'] = lambda x: swagger['securityDefinitions'][x]
     env.filters['has_payload'] = lambda x: any(param for param in x.get('parameters', []) if param['in'] == 'body')
+    env.filters['has_query_params'] = lambda x: any(
+        param for param in x.get('parameters', []) if param['in'] == 'query')
     # filter params by place (body, query, ...)
     env.filters['inside'] = lambda params, place: (p for p in params if p['in'] == place)
     swagger = safe_load(args.swagger.read_text())
 
+    security_type = swagger.get('x-go-credential-type', args.credential)
+
+    # apply default security
+    default_security = swagger.get('security', [])
+    if len(default_security) > 0:
+        for methods in swagger.get('paths', {}).values():
+            for endpoint in methods.values():
+                if 'security' not in endpoint:
+                    endpoint['security'] = default_security
+
     enums = tuple(iter_enums(swagger))
 
     base_file = args.output / "interfaces.go"
@@ -194,7 +206,7 @@ def main():
         header=f"// Code generated by simple-swagger {' '.join(sys.argv[1:])} DO NOT EDIT.",
         swagger=swagger,
         package=package,
-        credential_type=args.credential,
+        credential_type=security_type,
         api_package=api_package,
         enums=enums,
         has_security=len(
@@ -208,7 +220,7 @@ def main():
         swagger=swagger,
         package="server",
         enums=enums,
-        credential_type=args.credential,
+        credential_type=security_type,
         api_package=api_package,
         has_security=len(
             swagger.get('securityDefinitions', {})) > 0))
@@ -218,7 +230,7 @@ def main():
         swagger=swagger,
         package="client",
         enums=enums,
-        credential_type=args.credential,
+        credential_type=security_type,
         api_package=api_package,
         has_security=len(
             swagger.get('securityDefinitions', {})) > 0))
